===================================================================
:mod:`tensor.extra_ops` --  Tensor Extra Ops
===================================================================

.. testsetup:: *

   from aesara.tensor.extra_ops import *

.. module:: tensor.extra_ops
   :platform: Unix, Windows
   :synopsis: Tensor Extra Ops
.. moduleauthor:: LISA

.. automodule:: aesara.tensor.extra_ops
    :members:
